@@ -172,7 +172,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             page.set_default_navigation_timeout(self.default_navigation_timeout)
 
         # page.on("close", self._make_close_page_callback("default"))
-        page.on("crash", self._make_close_page_callback("default"))
+        # page.on("crash", self._make_close_page_callback("default"))
         page.on("request", _make_request_logger("default"))
         page.on("response", _make_response_logger("default"))
         page.on("request", self._increment_request_stats)
